@@ -9,4 +9,7 @@ utils::globalVariables(c("dataSet", "name.map", "Metabolite_pathway_table","KEGG
                          "createVisualStyle","setVisualStyle","lockNodeDimensions",
                          "setEdgeColorMapping","setEdgeLineWidthMapping","layoutNetwork","exportImage",
                          "L2cross_nopercent","L2cross","return.cols","pred","obs","prostate_df","PDSmatrix","Label",
-                         "X1", "X2","h2otrainDf","tpr","fpr","performance_data","selected_Pathways_Weka"))
+                         "X1", "X2","h2otrainDf","tpr","fpr","performance_data","selected_Pathways_Weka",
+                         "as.h2o", "h2o.F1", "h2o.accuracy", "h2o.auc", "h2o.find_threshold_by_max_metric",
+                         "h2o.getGrid", "h2o.getModel", "h2o.grid", "h2o.init", "h2o.performance",
+                         "h2o.precision", "h2o.sensitivity"))
